==> haskell-connection-0.2.6-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.6
id: connection-0.2.6-8r9cIfr65WPJ7qAiJ6jRBo
key: connection-0.2.6-8r9cIfr65WPJ7qAiJ6jRBo
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
abi: adc04d35de1963bf37c31e717f840e2d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/connection-0.2.6
hs-libraries: HSconnection-0.2.6-8r9cIfr65WPJ7qAiJ6jRBo
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 containers-0.5.7.1
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    socks-0.5.5-639qd4dP5FA2mjIZvcGBUX tls-1.3.8-AP2CWOA2Qcw6OdA165NwUU
    x509-1.6.4-AQd8BJOkfBD1up0H04WoXR
    x509-store-1.6.2-6UQrEcokOvBAMbtSL6B67o
    x509-system-1.6.4-CrURYUo0dGcGBeZJRT86ZU
    x509-validation-1.6.5-1wJ1PPg1FNLyGUX9VDyGO
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.2.6-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.6
id: connection-0.2.6-4fnWoCxQar39EBoMbmctKq
key: connection-0.2.6-4fnWoCxQar39EBoMbmctKq
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
abi: 984fa9af90b17951bbc4f80dc4172619
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/connection-0.2.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/connection-0.2.6
hs-libraries: HSconnection-0.2.6-4fnWoCxQar39EBoMbmctKq
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 containers-0.5.7.1
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    socks-0.5.5-639qd4dP5FA2mjIZvcGBUX tls-1.3.8-7W9MzOH2GSCDnAS4Jv8ix8
    x509-1.6.5-9ToKLiEGElbES8i9C1zzpo
    x509-store-1.6.2-BAi5tIxTCqTFE8lYFereda
    x509-system-1.6.4-FRo9BTOjzMgLvtYzPa0Nau
    x509-validation-1.6.5-Kygy3FC1rUkGp1msQcgAr7
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
